ChainError

Trait ChainError 

pub trait ChainError {
    // Required method
    fn chain_error<C>(self, context: C) -> StrError
       where C: IntoChained;
}
Trait providing chain_error for converting an error of any type to a StrError.

See crate level documentation for usage examples.

Required Methods

fn chain_error<C>(self, context: C) -> StrError
where C: IntoChained,

Convert an error of any type to a StrError, adding context.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<E> ChainError for E
where E: Into<Box<dyn Error + Send + Sync>>,